==> odoo_19.0.20251009.zip: odoo-19.0.post20251009/odoo/addons/spreadsheet/static/src/actions/helpers.js <==
/**
 * @typedef {import("@web/webclient/actions/action_service").ActionOptions} ActionOptions
 */

/**
 * @param {*} env
 * @param {string} actionXmlId
 * @param {Object} actionDescription
 * @param {ActionOptions} options
 */
export async function navigateTo(env, actionXmlId, actionDescription, options) {
    const actionService = env.services.action;
    let navigateActionDescription;
    const { views, view_mode, domain, context, name, res_model, res_id } = actionDescription;
    try {
        navigateActionDescription = await actionService.loadAction(actionXmlId, context);
        const filteredViews = views.map(
            ([v, viewType]) =>
                navigateActionDescription.views.find(([, type]) => viewType === type) || [
                    v,
                    viewType,
                ]
        );

        navigateActionDescription = {
            ...navigateActionDescription,
            context,
            domain,
            name,
            res_model,
            res_id,
            view_mode,
            target: "current",
            views: filteredViews,
        };
    } catch {
        navigateActionDescription = {
            type: "ir.actions.act_window",
            name,
            res_model,
            res_id,
            views,
            target: "current",
            domain,
            context,
            view_mode,
        };
    } finally {
        await actionService.doAction(
            // clear empty keys
            JSON.parse(JSON.stringify(navigateActionDescription)),
            options
        );
    }
}

==> odoo_19.2a1.20260108.zip: odoo-19.2a1.post20260108/odoo/addons/spreadsheet/static/src/actions/helpers.js <==
/**
 * @typedef {import("@web/webclient/actions/action_service").ActionOptions} ActionOptions
 */

/**
 * @param {*} env
 * @param {string} actionXmlId
 * @param {Object} actionDescription
 * @param {ActionOptions} options
 */
export async function navigateTo(env, actionXmlId, actionDescription, options) {
    const actionService = env.services.action;
    let navigateActionDescription;
    const { views, view_mode, domain, context, name, res_model, res_id } = actionDescription;
    try {
        navigateActionDescription = await actionService.loadAction(actionXmlId, context);
        const filteredViews = views
            ? views.map(
                  ([v, viewType]) =>
                      navigateActionDescription.views.find(([, type]) => viewType === type) || [
                          v,
                          viewType,
                      ]
              )
            : navigateActionDescription.views;

        navigateActionDescription = {
            ...navigateActionDescription,
            context,
            domain,
            name,
            res_model,
            res_id,
            view_mode,
            target: "current",
            views: filteredViews,
        };
    } catch {
        navigateActionDescription = {
            type: "ir.actions.act_window",
            name,
            res_model,
            res_id,
            views: views || [
                [false, "list"],
                [false, "form"],
                [false, "graph"],
                [false, "pivot"],
            ],
            target: "current",
            domain,
            context,
            view_mode,
        };
    } finally {
        await actionService.doAction(
            // clear empty keys
            JSON.parse(JSON.stringify(navigateActionDescription)),
            options
        );
    }
}
